%   HRIVC   Computes the Hammerstein continuous-time  model parameters from regular sampled I/O data
%	by the Hammerstein Refined Instrumental Variable for hybrid continuous-time Box-Jenkins model,
%
%       y(t) = [B(s)/F(s)]ubar(t) + [C(q)/D(q)]e(t)
%       ubar(t) = u1(t) + alpha1 u2(t) + ... + alphan un+1(t)
%       u1,u2...un(t) represent basics functions generated by the users.
%       included
%	Usage :
%
%       [Modlin, Infos] = hrivc(Z, nn, lambda0, t0, init_method, tol, maxiter, arma_method);
%
%   Modlin : returns the estimated linearized model in an IDPOLY object format
%       along with structure information.
%       y(t) = [B(s)/F(s)]u1(t) + alpha1[B(s)/F(s)]u2(t) +... + alphan[B(s)/F(s)]un+1(t) + e(t)
%       For the exact format of M see also help IDPOLY.
%   Infos is a structure containing the following fields
%   F         : coefficients of linear F polynomial
%   B         : coefficients of linear B polynomial
%   Nonlinfunc: coefficients of the nonlinear function
%   C         : coefficients of the MA noise model
%   D         : coefficients of the AR noise model
%   RT2       : coefficient of determination
%   YIC       : Young's Information Criterion
%   CN_P      : condition number of the Instrumental Product Matrix
%   AIC       : Akaike Information criterion
%   itnum     : number of iteration for convergence
%   present   : presentation of the model under hammerstein form
%
%   Z : The estimation data in IDDATA object format.
%       Data have to be equally sampled (see srivc for nonequally sampled data)
%       See help IDDATA
% 	nn = [nb nc nd nf nk] where
% 		 	 nb : number of parameters to be estimated for the numerator of the CT TF plant model
%            nc : number of parameters to be estimated for the MA part of the DT noise model
%            nd : number of parameters to be estimated for the AR part of the DT noise model
%            nf : number of parameters to be estimated for the denominator of the CT TF plant model
% 		  	 nk : delay of the model (integer number of sampling period Ts)
%
%	Optional Parameters :
%   lambda0 : [lambda(1) ... lambda(nu)]: cut-off frequency of the Poisson filter chain element
%             required for the initial parameter estimation by the ivgpmf routine
%             lambda(i) is the design parameter associated to the transfer function
%             of the ith input.
%   t0      : for regularly sampled data, t0=n0 is the starting estimation index (n0=t0/Ts)
%	          By default, it is set on to 1.
%   init_method : method used to initialize the srivc routine
%                 'sriv'  : discrete-time version of the SRIVC method
%                           'sriv' will be used by default in the case of equally sampled data
%                           The discrete-time model is converted into continuous-time
%                           does not require to specify lambda0.
%                 'ivgpmf': IV-based GPMF estimation method.
%                           the cut-off frequency (lambda0) can be then specified
%                           if it is not specified, then lambda0 is automatically set
%                           to ws/4 where ws is the sampling frequency in rad/sec
%                           'ivgpmf' will be used by default
%                               if lambda0 is given as third input argument,
%                 'lssvf' : LS-based SVF estimation method
%                           requires to specify lambda0
%   tol     : tolerance value (in %) on relative error of the estimated parameters,
%  	          tol is used to stop the iterative search (default value: 1e-2 %)
%   maxiter : maximum of loops for the iterations (default value: 50)
%   arma_method : method used to initialize the srivc routine
%                 'pem'   : use of the PEM SID toolbox method (default)
%                 'ivarma': use of the IVARMA CONTSID toolbox method (see
%                 help ivarma)


